@@ -16,7 +16,7 @@ from cca_zoo.deepmodels import (
     BarlowTwins,
     DCCA_SDL,
 )
-from cca_zoo.deepmodels import _objectives, _architectures
+from cca_zoo.deepmodels import objectives, architectures
 from cca_zoo.models import CCA
 
 manual_seed(0)
@@ -40,9 +40,27 @@ def test_DCCA_methods():
     latent_dims = 2
     epochs = 100
     cca = CCA(latent_dims=latent_dims).fit((X, Y))
+    # DCCA
+    encoder_1 = architectures.Encoder(latent_dims=latent_dims, feature_size=10)
+    encoder_2 = architectures.Encoder(latent_dims=latent_dims, feature_size=12)
+    dcca = DCCA(
+        latent_dims=latent_dims,
+        encoders=[encoder_1, encoder_2],
+        objective=objectives.CCA,
+    )
+    trainer = pl.Trainer(
+        max_epochs=epochs, log_every_n_steps=1, enable_checkpointing=False
+    )
+    trainer.fit(dcca, train_loader, val_dataloaders=val_loader)
+    assert (
+            np.testing.assert_array_less(
+                cca.score((X, Y)).sum(), dcca.score(train_loader, train=True).sum()
+            )
+            is None
+    )
     # DCCA_NOI
-    encoder_1 = _architectures.Encoder(latent_dims=latent_dims, feature_size=10)
-    encoder_2 = _architectures.Encoder(latent_dims=latent_dims, feature_size=12)
+    encoder_1 = architectures.Encoder(latent_dims=latent_dims, feature_size=10)
+    encoder_2 = architectures.Encoder(latent_dims=latent_dims, feature_size=12)
     dcca_noi = DCCA_NOI(latent_dims, N, encoders=[encoder_1, encoder_2], rho=0)
     trainer = pl.Trainer(
         max_epochs=epochs, log_every_n_steps=1, enable_checkpointing=False
@@ -50,43 +68,25 @@ def test_DCCA_methods():
     trainer.fit(dcca_noi, train_loader)
     assert (
         np.testing.assert_array_less(
-            cca.score((X, Y)).sum(), dcca_noi.batch_correlation(train_loader).sum()
-        )
-        is None
-    )
-    # DCCA
-    encoder_1 = _architectures.Encoder(latent_dims=latent_dims, feature_size=10)
-    encoder_2 = _architectures.Encoder(latent_dims=latent_dims, feature_size=12)
-    dcca = DCCA(
-        latent_dims=latent_dims,
-        encoders=[encoder_1, encoder_2],
-        objective=_objectives.CCA,
-    )
-    trainer = pl.Trainer(
-        max_epochs=epochs, log_every_n_steps=1, enable_checkpointing=False
-    )
-    trainer.fit(dcca, train_loader, val_dataloaders=val_loader)
-    assert (
-        np.testing.assert_array_less(
-            cca.score((X, Y)).sum(), dcca.batch_correlation(train_loader).sum()
+            cca.score((X, Y)).sum(), dcca_noi.score(train_loader).sum()
         )
         is None
     )
     # Soft Decorrelation (_stochastic Decorrelation Loss)
-    encoder_1 = _architectures.Encoder(latent_dims=latent_dims, feature_size=10)
-    encoder_2 = _architectures.Encoder(latent_dims=latent_dims, feature_size=12)
+    encoder_1 = architectures.Encoder(latent_dims=latent_dims, feature_size=10)
+    encoder_2 = architectures.Encoder(latent_dims=latent_dims, feature_size=12)
     sdl = DCCA_SDL(latent_dims, N, encoders=[encoder_1, encoder_2], lam=1e-2, lr=1e-3)
     trainer = pl.Trainer(max_epochs=epochs, log_every_n_steps=1)
     trainer.fit(sdl, train_loader)
     assert (
         np.testing.assert_array_less(
-            cca.score((X, Y)).sum(), sdl.batch_correlation(train_loader).sum()
+            cca.score((X, Y)).sum(), sdl.score(train_loader).sum()
         )
         is None
     )
     # Barlow Twins
-    encoder_1 = _architectures.Encoder(latent_dims=latent_dims, feature_size=10)
-    encoder_2 = _architectures.Encoder(latent_dims=latent_dims, feature_size=12)
+    encoder_1 = architectures.Encoder(latent_dims=latent_dims, feature_size=10)
+    encoder_2 = architectures.Encoder(latent_dims=latent_dims, feature_size=12)
     barlowtwins = BarlowTwins(
         latent_dims=latent_dims,
         encoders=[encoder_1, encoder_2],
@@ -97,17 +97,17 @@ def test_DCCA_methods():
     trainer.fit(barlowtwins, train_loader)
     assert (
         np.testing.assert_array_less(
-            cca.score((X, Y)).sum(), barlowtwins.batch_correlation(train_loader).sum()
+            cca.score((X, Y)).sum(), barlowtwins.score(train_loader).sum()
         )
         is None
     )
     # DGCCA
-    encoder_1 = _architectures.Encoder(latent_dims=latent_dims, feature_size=10)
-    encoder_2 = _architectures.Encoder(latent_dims=latent_dims, feature_size=12)
+    encoder_1 = architectures.Encoder(latent_dims=latent_dims, feature_size=10)
+    encoder_2 = architectures.Encoder(latent_dims=latent_dims, feature_size=12)
     dgcca = DCCA(
         latent_dims=latent_dims,
         encoders=[encoder_1, encoder_2],
-        objective=_objectives.GCCA,
+        objective=objectives.GCCA,
     )
     trainer = pl.Trainer(
         max_epochs=epochs, log_every_n_steps=1, enable_checkpointing=False
@@ -115,17 +115,17 @@ def test_DCCA_methods():
     trainer.fit(dgcca, train_loader)
     assert (
         np.testing.assert_array_less(
-            cca.score((X, Y)).sum(), dgcca.batch_correlation(train_loader).sum()
+            cca.score((X, Y)).sum(), dgcca.score(train_loader).sum()
         )
         is None
     )
     # DMCCA
-    encoder_1 = _architectures.Encoder(latent_dims=latent_dims, feature_size=10)
-    encoder_2 = _architectures.Encoder(latent_dims=latent_dims, feature_size=12)
+    encoder_1 = architectures.Encoder(latent_dims=latent_dims, feature_size=10)
+    encoder_2 = architectures.Encoder(latent_dims=latent_dims, feature_size=12)
     dmcca = DCCA(
         latent_dims=latent_dims,
         encoders=[encoder_1, encoder_2],
-        objective=_objectives.MCCA,
+        objective=objectives.MCCA,
     )
     trainer = pl.Trainer(
         max_epochs=epochs, log_every_n_steps=1, enable_checkpointing=False
@@ -133,7 +133,7 @@ def test_DCCA_methods():
     trainer.fit(dmcca, train_loader)
     assert (
         np.testing.assert_array_less(
-            cca.score((X, Y)).sum(), dmcca.batch_correlation(train_loader).sum()
+            cca.score((X, Y)).sum(), dmcca.score(train_loader).sum()
         )
         is None
     )
@@ -144,8 +144,8 @@ def test_DTCCA_methods():
     latent_dims = 2
     epochs = 150
     cca = CCA(latent_dims=latent_dims)
-    encoder_1 = _architectures.LinearEncoder(latent_dims=latent_dims, feature_size=10)
-    encoder_2 = _architectures.LinearEncoder(latent_dims=latent_dims, feature_size=12)
+    encoder_1 = architectures.LinearEncoder(latent_dims=latent_dims, feature_size=10)
+    encoder_2 = architectures.LinearEncoder(latent_dims=latent_dims, feature_size=12)
     dtcca = DTCCA(latent_dims=latent_dims, encoders=[encoder_1, encoder_2], lr=1e-2)
     trainer = pl.Trainer(max_epochs=epochs, enable_checkpointing=False)
     trainer.fit(dtcca, train_loader)
@@ -164,18 +164,10 @@ def test_DTCCA_methods():
 
 def test_DCCAE_methods():
     latent_dims = 2
-    encoder_1 = _architectures.CNNEncoder(
-        latent_dims=latent_dims, feature_size=(16, 16)
-    )
-    encoder_2 = _architectures.CNNEncoder(
-        latent_dims=latent_dims, feature_size=(16, 16)
-    )
-    decoder_1 = _architectures.CNNDecoder(
-        latent_dims=latent_dims, feature_size=(16, 16)
-    )
-    decoder_2 = _architectures.CNNDecoder(
-        latent_dims=latent_dims, feature_size=(16, 16)
-    )
+    encoder_1 = architectures.CNNEncoder(latent_dims=latent_dims, feature_size=(16, 16))
+    encoder_2 = architectures.CNNEncoder(latent_dims=latent_dims, feature_size=(16, 16))
+    decoder_1 = architectures.CNNDecoder(latent_dims=latent_dims, feature_size=(16, 16))
+    decoder_2 = architectures.CNNDecoder(latent_dims=latent_dims, feature_size=(16, 16))
     # SplitAE
     splitae = SplitAE(
         latent_dims=latent_dims, encoder=encoder_1, decoders=[decoder_1, decoder_2]
@@ -194,20 +186,20 @@ def test_DCCAE_methods():
 
 def test_DVCCA_p_methods():
     latent_dims = 2
-    encoder_1 = _architectures.Encoder(
+    encoder_1 = architectures.Encoder(
         latent_dims=latent_dims, feature_size=10, variational=True
     )
-    encoder_2 = _architectures.Encoder(
+    encoder_2 = architectures.Encoder(
         latent_dims=latent_dims, feature_size=12, variational=True
     )
-    private_encoder_1 = _architectures.Encoder(
+    private_encoder_1 = architectures.Encoder(
         latent_dims=latent_dims, feature_size=10, variational=True
     )
-    private_encoder_2 = _architectures.Encoder(
+    private_encoder_2 = architectures.Encoder(
         latent_dims=latent_dims, feature_size=12, variational=True
     )
-    decoder_1 = _architectures.Decoder(latent_dims=2 * latent_dims, feature_size=10)
-    decoder_2 = _architectures.Decoder(latent_dims=2 * latent_dims, feature_size=12)
+    decoder_1 = architectures.Decoder(latent_dims=2 * latent_dims, feature_size=10)
+    decoder_2 = architectures.Decoder(latent_dims=2 * latent_dims, feature_size=12)
     # DVCCA
     dvcca = DVCCA(
         latent_dims=latent_dims,
@@ -217,18 +209,19 @@ def test_DVCCA_p_methods():
     )
     trainer = pl.Trainer(max_epochs=5, log_every_n_steps=1, enable_checkpointing=False)
     trainer.fit(dvcca, train_loader)
+    dvcca.transform(train_loader)
 
 
 def test_DVCCA_methods():
     latent_dims = 2
-    encoder_1 = _architectures.Encoder(
+    encoder_1 = architectures.Encoder(
         latent_dims=latent_dims, feature_size=10, variational=True
     )
-    encoder_2 = _architectures.Encoder(
+    encoder_2 = architectures.Encoder(
         latent_dims=latent_dims, feature_size=12, variational=True
     )
-    decoder_1 = _architectures.Decoder(latent_dims=latent_dims, feature_size=10)
-    decoder_2 = _architectures.Decoder(latent_dims=latent_dims, feature_size=12)
+    decoder_1 = architectures.Decoder(latent_dims=latent_dims, feature_size=10)
+    decoder_2 = architectures.Decoder(latent_dims=latent_dims, feature_size=12)
     dvcca = DVCCA(
         latent_dims=latent_dims,
         encoders=[encoder_1, encoder_2],
@@ -239,8 +232,8 @@ def test_DVCCA_methods():
 
 
 def test_linear():
-    encoder_1 = _architectures.LinearEncoder(latent_dims=1, feature_size=10)
-    encoder_2 = _architectures.LinearEncoder(latent_dims=1, feature_size=12)
+    encoder_1 = architectures.LinearEncoder(latent_dims=1, feature_size=10)
+    encoder_2 = architectures.LinearEncoder(latent_dims=1, feature_size=12)
     dcca = DCCA(latent_dims=1, encoders=[encoder_1, encoder_2], lr=1e-1)
     trainer = pl.Trainer(max_epochs=100, enable_checkpointing=False)
     trainer.fit(dcca, loader)
@@ -248,7 +241,7 @@ def test_linear():
     # check linear encoder with SGD matches vanilla linear CCA
     assert (
         np.testing.assert_array_almost_equal(
-            cca.score((X, Y)), dcca.batch_correlation(loader), decimal=2
+            cca.score((X, Y)), dcca.score(loader), decimal=2
         )
         is None
     )
