@@ -4,6 +4,7 @@ import scipy.sparse as sp
 from sklearn.utils.fixes import loguniform
 from sklearn.utils.validation import check_random_state
 
+from cca_zoo import cross_validate, permutation_test_score, learning_curve
 from cca_zoo.data import generate_covariance_data
 from cca_zoo.model_selection import GridSearchCV, RandomizedSearchCV
 from cca_zoo.models import (
@@ -29,6 +30,7 @@ from cca_zoo.models import (
     StochasticPowerPLS,
     IncrementalPLS,
 )
+from cca_zoo.plotting import pairplot_train_test
 
 n = 50
 rng = check_random_state(0)
@@ -237,6 +239,21 @@ def test_stochastic():
     )
 
 
+def test_validation():
+    # Test that validation works
+    pls = PLS(latent_dims=1).fit((X, Y))
+    cross_validate(pls, (X, Y))
+    permutation_test_score(pls, (X, Y))
+    learning_curve(pls, (X, Y))
+
+
+def test_plotting():
+    pls = PLS(latent_dims=1).fit((X, Y))
+    X_te = np.random.rand(*X.shape)
+    Y_te = np.random.rand(*Y.shape)
+    pairplot_train_test(pls.transform((X, Y)), pls.transform((X_te, Y_te)))
+
+
 def test_PCCA():
     # some might not have access to jax/numpyro so leave this as an optional test locally.
     numpyro = pytest.importorskip("numpyro")
